@@ -40,22 +40,22 @@ class HunterService(Service):
         execute_shell_command("find %s -type f  | xargs rm " % self.results_dir)
         execute_shell_command("adb logcat -c")  # or   adb logcat -b all -c
 
-    def parseFile(self, filename, functions, instrument=False):
+    def parse_file(self, filename, functions, instrument=False):
         """array functions to decide which methods collect instrumentation data
         variable instrument to decide if array functions is an array of methods
         to collect information or to discard"""
         with open(filename, 'r') as filehandle:
             lines = filehandle.read().splitlines()
-            self.parseHistory(lines, functions, instrument)
+            self.parse_history(lines, functions, instrument)
 
-    def parseHistory(self, lines_list, functions, instrument=False, start_time=0, end_time=sys.maxsize):
+    def parse_history(self, lines_list, functions, instrument=False, start_time=0, end_time=sys.maxsize):
         for i, line in enumerate(lines_list):
             #print(line)
             if re.match(r"^>", line):
                 before_components = re.split('^>', line.replace(" ", ""))
                 components = re.split('[,=\[\]]', before_components[1])
                 function_name = components[0].replace("$", ".")
-                add_function = self.verifyFunction(function_name, functions, instrument)
+                add_function = self.verify_function(function_name, functions, instrument)
                 begin_time = components[6]
                 if add_function and float(begin_time) >= start_time:    
                     if function_name not in self.trace:
@@ -68,19 +68,19 @@ class HunterService(Service):
                 before_components = re.split('^<', line.replace(" ", ""))
                 components = re.split('[,=\[\] ]', before_components[1])
                 function_name = components[0].replace("$", ".")
-                add_function = self.verifyFunction(function_name, functions, instrument)
+                add_function = self.verify_function(function_name, functions, instrument)
                 close_time = float(components[6])
                 if close_time > end_time:
                     #remove func
                     print("todo: remove function from obj")
                 if add_function:
                     close_time = components[6]
-                    self.updateTraceReturn(function_name, close_time)
+                    self.update_trace_return(function_name, close_time)
             else:
                 pass
                 #log("invalid line" + line)
 
-    def addConsumption(self, function_name, position, consumption, per_component_consumption, metrics):
+    def add_consumption(self, function_name, position, consumption, per_component_consumption, metrics):
         self.trace[function_name][position].update(
             {
                 'checked': False,
@@ -90,7 +90,7 @@ class HunterService(Service):
             }
         )
 
-    def addConsumptionToTraceFile(self, filename, functions, instrument=False):
+    def add_consumption_to_trace_file(self, filename, functions, instrument=False):
         new_filename = filename.replace(os.path.basename(filename), os.path.basename(filename).replace("hunter-", "truncated_hunter-"))
         with open(filename, 'r+') as fr, open(new_filename, 'w') as fw:
             for line in fr:
@@ -108,9 +108,9 @@ class HunterService(Service):
                     checked = True
                     function_begin = "<"
 
-                add_function = self.verifyFunction(function_name, functions, instrument)
+                add_function = self.verify_function(function_name, functions, instrument)
                 if add_function:
-                    consumption, time = self.returnConsumptionAndTimeByFunction(function_name, checked)
+                    consumption, time = self.return_consumption_and_time_by_function(function_name, checked)
                     new_line = function_begin + function_name + " [m=example, " + 'cpu = ' + str(
                         consumption) + ', t = ' + str(time) + ']\n'
                     fw.write(new_line)
@@ -121,7 +121,7 @@ class HunterService(Service):
     '''
         Returns cpu consumption instead total consumption
     '''
-    def returnConsumptionAndTimeByFunction(self, function_name, checked):
+    def return_consumption_and_time_by_function(self, function_name, checked):
         consumption = 0.0
         cpu_consumption = 0.0
         da_time = 0.0
@@ -134,20 +134,20 @@ class HunterService(Service):
                     cpu_consumption = per_component_consumption['cpu']
 
                     da_time = results['end_time'] if 'end_time' in results else self.end_time
-                    self.updateChecked(function_name, i)
+                    self.__update_checked(function_name, i)
                     return cpu_consumption, da_time
                 da_time = results['begin_time']
                 return cpu_consumption, da_time
         return cpu_consumption, da_time
 
-    def updateChecked(self, function_name, position):
+    def __update_checked(self, function_name, position):
         self.trace[function_name][position].update(
             {
                 'checked': True
             }
         )
 
-    def updateTraceReturn(self, function_name, end_time):
+    def update_trace_return(self, function_name, end_time):
         i = len(self.trace[function_name]) - 1 if function_name in self.trace else -1
         while i >= 0:
             times = self.trace[function_name][i]
@@ -161,7 +161,7 @@ class HunterService(Service):
 
     # Verify if it is to add the function to hunter_trace or get consumption
     @staticmethod
-    def verifyFunction(function_name, functions, add_function=False):
+    def verify_function(function_name, functions, add_function=False):
         if len(functions) == 0:
             return True
         res = not add_function
